#
# spec file for package python-dfVFS
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define timestamp 20231208
Name:           python-dfVFS
Version:        0~%{timestamp}
Release:        2.1
Summary:        Digital Forensics Virtual File System
License:        Apache-2.0
Group:          Productivity/File utilities
URL:            https://github.com/log2timeline/dfvfs/wiki
Source0:        https://github.com/log2timeline/dfvfs/releases/download/%{timestamp}/dfvfs-%{timestamp}.tar.gz
Source99:       python-dfVFS-rpmlintrc
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module dfdatetime}
BuildRequires:  %{python_module dtfabric >= 20220219}
BuildRequires:  %{python_module idna}
BuildRequires:  %{python_module libbde}
BuildRequires:  %{python_module libcaes}
BuildRequires:  %{python_module libewf}
BuildRequires:  %{python_module libfsapfs}
BuildRequires:  %{python_module libfsext}
BuildRequires:  %{python_module libfsfat}
BuildRequires:  %{python_module libfshfs}
BuildRequires:  %{python_module libfsntfs}
BuildRequires:  %{python_module libfsxfs}
BuildRequires:  %{python_module libfvde}
BuildRequires:  %{python_module libfwnt}
BuildRequires:  %{python_module libluksde >= 20220121}
BuildRequires:  %{python_module libmodi}
BuildRequires:  %{python_module libphdi}
BuildRequires:  %{python_module libqcow}
BuildRequires:  %{python_module libsigscan >= 0~20191221}
BuildRequires:  %{python_module libsmdev}
BuildRequires:  %{python_module libsmraw}
BuildRequires:  %{python_module libvhdi}
BuildRequires:  %{python_module libvmdk}
BuildRequires:  %{python_module libvsapm}
BuildRequires:  %{python_module libvsgpt}
BuildRequires:  %{python_module libvshadow}
BuildRequires:  %{python_module libvslvm}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tsk}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-cffi
Requires:       python-construct
Requires:       python-cryptography
Requires:       python-dfdatetime >= 0~20180110
Requires:       python-dtfabric >= 20220219
Requires:       python-idna
Requires:       python-libbde
Requires:       python-libcaes
Requires:       python-libewf
Requires:       python-libfsapfs
Requires:       python-libfsext
Requires:       python-libfsfat
Requires:       python-libfshfs
Requires:       python-libfsntfs >= 0~20160418
Requires:       python-libfsxfs
Requires:       python-libfvde
Requires:       python-libfwnt >= 20210717
Requires:       python-libluksde >= 20220121
Requires:       python-libmodi
Requires:       python-libphdi
Requires:       python-libqcow
Requires:       python-libsigscan
Requires:       python-libsmdev
Requires:       python-libsmraw
Requires:       python-libvhdi
Requires:       python-libvmdk
Requires:       python-libvsapm
Requires:       python-libvsgpt
Requires:       python-libvshadow >= 0~20170902
Requires:       python-libvslvm
Requires:       python-tsk >= 0~20160721
Obsoletes:      python3-dfVFS < 0~%{timestamp}
BuildArch:      noarch
%python_subpackages

%description
dfVFS, or Digital Forensics Virtual File System, provides read-only
access to file-system objects from various storage media types and file
formats. The goal of dfVFS is to provide a generic interface for
accessing file-system objects, for which it uses several back-ends that
provide the actual implementation of the various storage media types,
volume systems and file systems.

dfVFS originates from the Plaso project and is also based on ideas from
the GRR project. It was largely rewritten and made into a stand-alone
project to provide more flexibility and allow other projects to make use
of the VFS functionality. dfVFS originally was named PyVFS, but that
name conflicted with another project.

dfVFS is currently implemented as a Python module.

%prep
%setup -q -n dfvfs-%{timestamp}
%autopatch -p1

find dfvfs -name \*.py | xargs sed -i "/#!\/usr\/bin\/python/d"
chmod -x utils/check_dependencies.py
chmod -x run_tests.py

%build
%pyproject_wheel

%install
%pyproject_install

%fdupes %{buildroot}

%check
%if 0%{?suse_version} && 0%{?suse_version} > 1560
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python ./run_tests.py
}
%endif

%files %{python_files}
%license LICENSE
%doc ACKNOWLEDGEMENTS AUTHORS README
%doc utils/check_dependencies.py utils/dependencies.py
# these are installed into the wrong place
%exclude %{_datadir}/doc/dfvfs/
%{python_sitelib}/dfvfs
%{python_sitelib}/dfvfs-%{timestamp}.dist-info

%changelog
* Wed Jun 18 2025 Steve Kowalik <steven.kowalik@suse.com>
- Use pyproject macros to build and install.
* Sat Jan 27 2024 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20231208
  - minor changes
- add Requires python-cffi [likely did previously -- lint complained
- add Requires python-idna [likely did previously -- lint complained
- APFS related python tests for 15.5 and 15.6 still fail. Extended test exclusion to 15.6
* Thu Aug 10 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20230531
  - add APM support [Apple Partition Map]
- add BuildRequires pyvsapm
- remove BuildRequires python-pbr
* Sat Aug  5 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- add conditional to only run python tests for factory.  15.4 and 15.5 are both failing for APFS filesystem checks
* Fri Jul 28 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} to select python versions
* Wed Apr  5 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- re-enable %%check section as the built-in tests now all pass
  - -
* Wed Mar  8 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20221224
  - Added support for empty GPT with MBR partitions
  - Added CoreStorage volume system
  - improved handling of bad ZIP files
  - see git commit log for additional changes
* Fri Dec 16 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- Add requirements on more Python modules
* Fri Dec 16 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- Upstream libyal/plaso is only supporting python 3.7 or newer
  - Add BuildRequires:  %%{python_module base >= 3.7}
* Thu Dec  1 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20220917
  - Changes for empty APFS volumes
  - Changes to expose extended attribute extents
  - Added empty volume support to file system searcher
  - Added APFS number of links support
  - Extended StatAttribute with device number
  - Changes to ZIP file entry for latest dfDateTime
  - Added ISO9660 test file and tests
- add BuildRequires python-libcaes
- add BuildRequires python-libfsfat
- re-disable %%check section as the built-in tests fail again for most APFS tests
- ran spec-cleaner
* Fri Sep 23 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove Requires:  python-six
  - This is untested as it is difficult to have an opensuse release without python-six at this point
* Tue Jun  7 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- allow multiple python packages to be built (eg. python38, python39, python310)
  - rm %%define pythons python38
  - add %%Obsoletes python3-dfVFS
  - add %%define skip_python2 1
* Tue May 31 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20220419
  - changes to support python-dtfabric 20220219
  - update methods for working with GPT and HFS+ volumes
- add BuildRequires libphdi   required to provide Parallels Disk Image support
- re-enable %%check section as the built-in tests now all pass
- update requires libluksde to require a current version
- update requires python-dtfabric to require a current version
* Mon May 23 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20211228
  - deprecated GetStat file entry method
- Manually run tests results in:
  - Ran 1228 tests in 299.931s
  - NO errors reported!
- update to 20211017
  - changes to support pyfwnt 20210717
  - added pyxattr to add attribute support for multiple filesystems
  - added size entry for ext, XFS, HFS file entries
- update to 20210606
  - added pymodi to support Mac OS disk images
  - API changes related to time objects to be compatible with newer dependency versions
- added BuildRequires:  %%{python_module libmodi}
- added Requires:  python-libmodi
- update to 20210213
  - added pyvsgpt to support hybrid GPT partition table setups
  - added pyvsxfs to support XFS filesystem support
  - moved examples folder to new github project dfvfs-snippets
- added BuildRequires:  %%{python_module libvsgpt}
- added BuildRequires:  %%{python_module libvsxfs}
- added Requires:  python-libvsgpt
- added Requires:  python-libvsxfs
- remove  %%doc examples
  - no longer provided in source tarball, moved to dfvfs-snippets github project
- remove lintrc reference to examples as examples have been removed
- update to 20201219
  - added fsext backend
  - changes to expose HFS+ create time
  - added fshfs backend
  - added fsxfs backend
  - added QCOW differential image support
* Tue May 17 2022 pgajdos@suse.com
- python-mock is not required for build (even if the testsuite
  would run)
* Sun Apr 25 2021 Ben Greiner <code@bnavigator.de>
- The majority of dependencies is available for the primary python3
  flavor only. Do the same.
* Sun Nov  8 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- Update to 20200920
  - Changes to make fsntfs the preferred NTFS back-end
  - Changes to make OS backend more error tollerant
  - Changes to make NTFS backend more error tollerant
  - Changes to OS file entry for creation time #440 and ns timestamps
  - Added XZ compressed stream analyzer
  - Added VHDX storage media image support
  - Changes to expose HFS+ creation time
  - Added fshfs back-end
- examples is no longer installed into the site folder. Remove the rename statement.
- add requires for libfsext, libfshfs, libluksde
- updated %%fdupes line to eliminate RPM warnings
* Sun Apr  5 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- Update to 20200211
  - Added volume scanner options (#346)
  - fixed failing test (#425)
  - Added LUKS support (#418)
  - Added initial APFS support
- Add Requires python-dtfabric - testing found not all use cases work without it
- Add Requires python-fsapfs   - testing found not all use cases work without it
- removed the %%check section - it is failing on newly added APFS support - not yet reliable
- Once again builds successfully against factory/tumbleweed
* Fri Jan 24 2020 Matej Cepl <mcepl@suse.com>
- Update to 20200121
- Remove include-examples-in-packages.patch as it is included
  upstream.
* Sat Jan 18 2020 Matej Cepl <mcepl@suse.com>
- Update to 20200117:
  - switch from PyCrypto to cryptography.io (Hurrah!)
  - test suite passes (gh#log2timeline/dfvfs#421)
- add patch: include-examples-in-packages.patch
* Tue Jan 14 2020 Matej Cepl <mcepl@suse.com>
- update to 20190902
  - back to Python singlespec and python3
* Thu Jan 11 2018 Greg.Freemyer@gmail.com
- update to v0~20171230
  * add more python3 support (even though openSUSE package doesn't use it)
  * bug fixes
  * compatible with plaso 20171231
- revert effort to use Python singlespec.  It's just not working smoothly.
* Mon Oct  2 2017 Greg.Freemyer@gmail.com
- update to v0~20170723
  * worked on internal test structure
- add python3 support
- implement python singlespec syntax
- In Requires: lines for libyal python bindings, use the python-lib* variant of the package
  Python singlespec automatically converts that to python2 / python3 as appropriate
- remove Requres: python-protobuf.  It has been replaced by a JSON solution
- adopt upstream name of python{23}-tsk3
* Sun Feb 26 2017 Greg.Freemyer@gmail.com
- correct Requires to have 0~ prefix
* Thu Jul 14 2016 Greg.Freemyer@gmail.com
- update to v0~20160918
  * still pre-release and no ChangeLog available
  * add requires pyfwnt, pyvslvm, python-dfdatetime
* Wed Dec  2 2015 Greg.Freemyer@gmail.com
- update to v0~20160108
  * still pre-release and no ChangeLog available
  * required by plaso v1.4.0 which is in feature freeze at this point
- update pyvshadow requires to version v0~20160110
- add Requires: pyfsntfs
* Wed Jul  1 2015 Greg.Freemyer@gmail.com
- update to v0~20150708
  * warning, breaks plaso prior to v1.3.0rc2
  * still pre-release and no ChangeLog available
* Fri May  8 2015 Greg.Freemyer@gmail.com
- update to v0~20150408
  * Plaso is the primary consumer of dfVFS, but it can be used standalone and may have other consumers in the future
  * Warning breaks JSON serialization in plaso and require a plaso version of 20150507 or later.
* Wed Mar 25 2015 Greg.Freemyer@gmail.com
- update to v0~20150303
  * dfVFS is in a rapid state of development and Changelog entries have not been implemented by upstream
- add Requires: pysigscan, it is a new dependency
- add a new %%exclude in %%files due to doubly included %%doc files
- remove spec file entry deleting installed examples.  Resolved upstream.
  * see https://github.com/log2timeline/dfvfs/issues/4
- chmod run_tests.py to remove the executable bits.  Was causing a rmplint warning.
* Wed Jan 21 2015 Greg.Freemyer@gmail.com
- update to v0~20150108
  * bugfix for auto-dependency build
- add explicit "%%py_compile ." to resolve rpmlint complaint about datestamps not matching
- add the examples folder to the %%doc section of %%files
- add run_tests.py to the %%doc section of %%files
* Mon Dec 22 2014 Greg.Freemyer@gmail.com
- upgrade to v0~20141220
  * dfVFS is in a rapid state of development and Changelog entries have not been implemented by upstream
- v0~20141220 required by latest plaso release
- update Url field to point to the new github site
- update source to be complete URL
- delete DL_URL field
- add an exclude for the "examples" that are provided.  They need a better namespace.
- add check_dependencies.py to %%doc so that users can verify they have usable dependencies
* Thu Aug 21 2014 Greg.Freemyer@gmail.com
- add a %%doc line to %%files section
- change the license tag to Apache-2.0
- add Requires libvmdk since it is now in OBS
- add Requires libvhdi since it is now in OBS
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- add missing "Requires: pyqcow" line to specfile
- remove %%attr(755...) line and instead use sed to remove #!/usr/bin/python from *py files
- cleanup Requires: in general
* Mon Aug 18 2014 Greg.Freemyer@gmail.com
- initial version in OBS (version 0~20140727)
